==> smplot2_0.2.3.tar.gz: smplot2/README.md <==
<p align="center">
  <img src="man/figures/logo.png" height="150px" width="135px" align="right">
  <h1><strong>smplot2</strong> - An R package for plotting standalone and composite figures</h1>
</p>

[![](http://cranlogs.r-pkg.org/badges/grand-total/smplot2?color=green)](https://cran.r-project.org/package=smplot2)
[![](https://cranlogs.r-pkg.org/badges/smplot2?color=green)](https://cran.r-project.org/package=smplot2) [![](https://img.shields.io/badge/devel%20version-0.2.3-black.svg)](https://github.com/smin95/smplot2) [![CRAN_Release_Badge](http://www.r-pkg.org/badges/version-ago/smplot2?color=green)](https://CRAN.R-project.org/package=smplot2) 

Author: Seung Hyun (Sam) Min

**smplot2** (SM: **S**eung Hyun **M**in) is an R package for statistical data visualization that complements ggplot2. This package represents what I wish I had back when I was beginning to learn R. It aims to make every step of data visualization easy.

**smplot** was first created in May 2021, and due to the numerous deprecated and newly created primary functions, **smplot** has now evolved into **smplot2**.

Key functionalities include shortcuts for plotting elegant figures that are appropriate for scientific journals and functions that facilitate generating and annotating composite figures.

### Installation using RStudio

You can install the released version of *smplot2* from CRAN.

```r
install.packages('smplot2')
```

The development version can be directly downloaded here:

``` r
install.packages("devtools")
devtools::install_github('smin95/smplot2')
```
 
To access an updated tutorial (sample codes and figures) of the package, please visit https://smin95.github.io/dataviz/.

==> smplot2_0.2.4.tar.gz: smplot2/README.md <==
<p align="center">
  <img src="man/figures/logo.png" height="150px" width="135px" align="right">
  <h1><strong>smplot2</strong> - An R package for plotting standalone and composite figures</h1>
</p>

[![](http://cranlogs.r-pkg.org/badges/grand-total/smplot2?color=green)](https://cran.r-project.org/package=smplot2)
[![](https://cranlogs.r-pkg.org/badges/smplot2?color=green)](https://cran.r-project.org/package=smplot2) [![](https://img.shields.io/badge/devel%20version-0.2.3.1-black.svg)](https://github.com/smin95/smplot2) [![CRAN_Release_Badge](http://www.r-pkg.org/badges/version-ago/smplot2?color=green)](https://CRAN.R-project.org/package=smplot2) 

Author: Seung Hyun (Sam) Min

**smplot2** (SM: **S**eung Hyun **M**in) is an R package for statistical data visualization that complements ggplot2. This package represents what I wish I had back when I was beginning to learn R. It aims to make every step of data visualization easy.

**smplot** was first created in May 2021, and due to the numerous deprecated and newly created primary functions, **smplot** has now evolved into **smplot2**.

Key functionalities include shortcuts for plotting elegant figures that are appropriate for scientific journals and functions that facilitate generating and annotating composite figures.

### Installation using RStudio

You can install the released version of *smplot2* from CRAN.

```r
install.packages('smplot2')
```

The development version can be directly downloaded here:

``` r
install.packages("devtools")
devtools::install_github('smin95/smplot2')
```
 
To access an updated tutorial (sample codes and figures) of the package, please visit https://smin95.github.io/dataviz/.
